@@ -387,20 +387,24 @@ class Sequential():
             elif epoch+1 == epochs:
                 if self.val_inputs is not None and self.val_targets is not None:
                     self.runtime = time.time() - start
-                    line_length = (len("[") + len(str(epoch+1)) + len("/") + len(str(epochs)) + len("] | train_loss: ") + len(str(np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5))) + len(" · val_loss: ") + len(str(np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5))) + len(" | train_accuracy: ") + len(str(np.around(self.accuracy(self.train_targets,self.train_outputs),5))) + len(" · val_accuracy: ") + len(str(np.around(self.accuracy(self.val_targets,self.val_outputs),5))) + len(" | runtime: ") + len(str(round(self.runtime,5))))
-                    print(line_length * "-" + f"\n[{epoch+1}/{epochs}] | train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} | val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)} | runtime: {round(self.runtime,5)}\n" + line_length * "-")
+                    line_length1 = len(f"| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |")
+                    line_length2 = len(f"| val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}")
+                    print(line_length1 * "-" + f"\n| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |\n" + line_length1 * "-" + f"\n| val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}" + (line_length1-line_length2-1) * " " + "|\n" + line_length1 * "-")
+                    print(f"{round(self.runtime, 5)} seconds")
                 else:
                     self.runtime = time.time() - start
-                    line_length = (len("[") + len(str(epoch+1)) + len("/") + len(str(epochs)) + len("] | train_loss: ") + len(str(np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5))) + len(" | train_accuracy: ") + len(str(np.around(self.accuracy(self.train_targets,self.train_outputs),5))) + len(" | runtime: ") + len(str(round(self.runtime,5))))
-                    print(line_length * "-" + f"\n[{epoch+1}/{epochs}] | train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} | train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} | runtime: {round(self.runtime,5)}\n" + line_length * "-")
+                    line_length1 = len(f"| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |")
+                    print(line_length1 * "-" + f"\n| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |\n" + line_length1 * "-")
+                    print(f"{round(self.runtime, 5)} seconds")
         elif verbose == 1:
             if epoch+1 == epochs:
                 if self.val_inputs is not None and self.val_targets is not None:
-                    line_length = (len("train_loss: ") + len(str(np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5))) + len(" · val_loss: ") + len(str(np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5))) + len(" | train_accuracy: ") + len(str(np.around(self.accuracy(self.train_targets,self.train_outputs),5))) + len(" · val_accuracy: ") + len(str(np.around(self.accuracy(self.val_targets,self.val_outputs),5))))
-                    print("\n" + line_length * "-" + f"\ntrain_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} | val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}\n" + line_length * "-")
+                    line_length1 = len(f"| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |")
+                    line_length2 = len(f"| val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}")
+                    print("\n" + line_length1 * "-" + f"\n| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |\n" + line_length1 * "-" + f"\n| val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}" + (line_length1-line_length2-1) * " " + "|\n" + line_length1 * "-")
                 else:
-                    line_length = (len("train_loss: ") + len(str(np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5))) + len(" | train_accuracy: ") + len(str(np.around(self.accuracy(self.train_targets,self.train_outputs),5))))
-                    print("\n" + line_length * "-" + f"\ntrain_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} | train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)}\n" + line_length * "-")
+                    line_length = len(f"| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |")
+                    print("\n" + line_length * "-" + f"\n| train_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} |\n" + line_length * "-")
         elif verbose == 0:
             return 
         else:
