@@ -46,7 +46,7 @@ class OneHotEncoder():
     
     def transform(self, y):
         import numpy as np
-        self.y = y
+        self.y = np.copy(y)
         self.L4 = []
         if self.fit == False:
             self.L1 = []
@@ -79,11 +79,11 @@ class StringEncoder():
     def transform(self, X):
         import numpy as np
         from melpy.preprocessing import OneHotEncoder
-        self.X = X
+        self.X = np.copy(X)
   
-        def is_string(x):
-            for i in range(len(x[0,:])):
-                if type(x[0,i]) == str:
+        def is_string(X):
+            for i in range(len(X[0,:])):
+                if type(X[0,i]) == str:
                     return True
             return False
         
@@ -125,7 +125,7 @@ class FeatureEncoder():
     def fit_transform(self, X, index):
         import numpy as np
         from melpy.preprocessing import OneHotEncoder
-        self.X = X
+        self.X = np.copy(X)
 
         self.feature_indices.append(index)
         self.encoders.append(OneHotEncoder())
@@ -141,7 +141,7 @@ class FeatureEncoder():
     
     def transform(self, X):
         import numpy as np
-        self.X = X
+        self.X = np.copy(X)
         
         if self.fit == True:
             for i in range(len(self.feature_indices)):
@@ -153,4 +153,43 @@ class FeatureEncoder():
             return self.X     
         
         else:
-            raise RuntimeError("encoder not fit")
\ No newline at end of file
+            raise RuntimeError("encoder not fit")
+
+class SimpleImputer():
+    def transform(self, X, column, missing_values="nan", strategy="mean"):
+        import numpy as np
+        self.X = np.copy(X)
+        self.column = column
+        self.missing_values = missing_values
+        self.strategy = strategy
+        
+        if self.strategy != "mean":
+            raise ValueError("invalid value for 'strategy'")
+            
+        if self.strategy == "mean":
+            if self.X[:,self.column].dtype == "<U4":
+                raise TypeError("invalid type for 'X[:,i]'")
+            
+            if self.missing_values == "nan":
+                mean = np.nanmean(np.array(self.X[:,self.column], dtype=np.float64))
+            else:
+                def ColMean():
+                    values = list(self.X[:,self.column].flatten())
+                    for i in range(len(values)):
+                        if i+1 > len(values):
+                            break
+                        if values[i] == self.missing_values:
+                            values.pop(i)
+                    mean = np.mean(values)
+                    return mean
+                
+                mean = ColMean()
+            
+            for i in range(len(self.X[:,0])):
+                if self.missing_values == "nan":
+                    if np.isnan(self.X[i,self.column]):
+                        self.X[i,self.column] = float(mean)
+                else:
+                    if self.X[i,self.column] == self.missing_values:
+                        self.X[i,self.column] = float(mean)
+            return self.X
\ No newline at end of file
